@@ -1,5 +1,5 @@
 /**
- * Copyright (c) Istituto Nazionale di Fisica Nucleare, 2006-2012.
+ * Copyright (c) Istituto Nazionale di Fisica Nucleare, 2006-2014.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -20,19 +20,22 @@ import java.util.List;
 
 /**
  * 
- * A strategy for looking up a set of VOMS Attribute Certificates from a certificate chain.
+ * A strategy for looking up a set of VOMS Attribute Certificates from a
+ * certificate chain.
  * 
  * @author Andrea Ceccanti
  *
  */
 public interface VOMSACLookupStrategy {
-	
-	/**
-	 * This method defines how a set of VOMS Attribute Certificates is looked for in a certificate
-	 * chain.
-	 * 
-	 * @return a {@link List} of {@link ACParsingContext} that describes the lookup outcome
-	 */
-	public List<ACParsingContext> lookupVOMSAttributeCertificates(X509Certificate[] certChain);
+
+  /**
+   * This method defines how a set of VOMS Attribute Certificates is looked for
+   * in a certificate chain.
+   * 
+   * @return a {@link List} of {@link ACParsingContext} that describes the
+   *         lookup outcome
+   */
+  public List<ACParsingContext> lookupVOMSAttributeCertificates(
+    X509Certificate[] certChain);
 
 }
