@@ -1,5 +1,5 @@
 /**
- * Copyright (c) Istituto Nazionale di Fisica Nucleare, 2006-2012.
+ * Copyright (c) Istituto Nazionale di Fisica Nucleare, 2006-2014.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,25 +15,28 @@
  */
 package org.italiangrid.voms.store.impl;
 
-
 /**
- * An helper class to create a named VOMS thread.
- * This class just sets the name for the thread and set an {@link java.lang.Thread.UncaughtExceptionHandler}
+ * An helper class to create a named VOMS thread. This class just sets the name
+ * for the thread and set an {@link java.lang.Thread.UncaughtExceptionHandler}
  * which logs the caught exception.
  * 
  * @author Andrea Ceccanti
  *
  */
 public class VOMSThread extends Thread {
-	
-	/**
-	 * Default constructor.
-	 * 
-	 * @param target the object whose <code>run</code> method is called.
-	 * @param name the name of the new thread.
-	 */
-	public VOMSThread(Runnable target, String name, UncaughtExceptionHandler handler) {
-		super(target, name);
-		setUncaughtExceptionHandler(handler);
-	}	
+
+  /**
+   * Default constructor.
+   * 
+   * @param target
+   *          the object whose <code>run</code> method is called.
+   * @param name
+   *          the name of the new thread.
+   */
+  public VOMSThread(Runnable target, String name,
+    UncaughtExceptionHandler handler) {
+
+    super(target, name);
+    setUncaughtExceptionHandler(handler);
+  }
 }
